@@ -13,7 +13,7 @@ use parent 'Plack::Session::Store';
 
 use constant SESSIONS_PER_SCAN => 100;
 
-our $VERSION   = '0.02';
+our $VERSION   = '0.03';
 our $AUTHORITY = 'cpan:AKZHAN';
 
 sub new {
@@ -22,13 +22,12 @@ sub new {
     $param{expire} = ONE_MONTH         unless exists $param{expire};
 
     unless ( $param{redis} ) {
-        my $builder = $param{builder} || \&_build_redis;
-        delete $param{builder};
-        $param{redis} = $builder->( $param{inflate}, $param{deflate} );
+        my $builder = ( delete $param{builder} ) || \&_build_redis;
+        $param{redis} = $builder->();
     }
 
     $param{encoder} ||=
-      _build_encoder( delete $param{inflate}, delete $param{deflate} );
+      _build_encoder( ( delete $param{inflate} ), ( delete $param{deflate} ) );
 
     $param{encoder} = $param{encoder}->new()
       unless ref( $param{encoder} );
